@@ -1,6 +1,6 @@
 package SPVM::Net::SSLeay;
 
-our $VERSION = "0.032";
+our $VERSION = "0.033";
 
 1;
 
@@ -14,10 +14,6 @@ Net::SSLeay class in L<SPVM> is a OpenSSL binding to SPVM.
 
 This class itself represents L<SSL|https://docs.openssl.org/master/man3/SSL> data structure in OpenSSL.
 
-B<Warnings:>
-
-B<This class is highly experimental. Many features may be changed without warnings.> 
-
 =head1 Usage
 
   use Net::SSLeay;
@@ -180,7 +176,7 @@ Note:
 
 Access to the global L<Hash|SPVM::Hash> object is locked by a L<Sync::Mutex|SPVM::Sync::Mutex> object, so the access is thread-safe.
 
-This callback hack is also used in L<Net::SSLeay::SSL_CTX|SPVM::Net::SSLeay::SSL_CTX> class.
+This callback hack is also used in L<Net::SSLeay::SSL_CTX|SPVM::Net::SSLeay::SSL_CTX> class. In this case, native C<SSL> object in the document is replaced with native C<SSL_CTX> object. And L<Net::SSLeay|SPVM::Net::SSLeay> object in the document is replaced with L<Net::SSLeay::SSL_CTX|SPVM::Net::SSLeay::SSL_CTX> object.
 
 =head2 Config Builder
 
