@@ -10,7 +10,7 @@ SPVM::Net::SSLeay::X509_CRL - X509_CRL data structure in OpenSSL
 
 =head1 Description
 
-Net::SSLeay::X509_CRL class in L<SPVM> represents L<X509_CRL|https://docs.openssl.org/3.1/man3/X509_CRL_new/> data structure in OpenSSL
+Net::SSLeay::X509_CRL class in L<SPVM> represents C<X509_CRL> data structure in OpenSSL
 
 =head1 Usage
 
@@ -22,7 +22,7 @@ Net::SSLeay::X509_CRL class in L<SPVM> represents L<X509_CRL|https://docs.openss
 
 C<static method new : L<Net::SSLeay::X509_CRL|SPVM::Net::SSLeay::X509_CRL> ();>
 
-Calls native L<X509_CRL_new|https://docs.openssl.org/1.1.1/man3/X509_dup/> function, creates a new  L<Net::SSLeay::X509_CRL|SPVM::Net::SSLeay::X509_CRL> object, sets the pointer value of the object to the return value of the native function, and returns the new object.
+Calls native L<X509_CRL_new|https://docs.openssl.org/master/man3/X509_CRL_new> function, creates a new  L<Net::SSLeay::X509_CRL|SPVM::Net::SSLeay::X509_CRL> object, sets the pointer value of the object to the return value of the native function, and returns the new object.
 
 Exceptions:
 
@@ -34,11 +34,11 @@ If X509_CRL_new failed, an exception is thrown with C<eval_error_id> set to the
 
 C<method get_REVOKED : L<Net::SSLeay::X509_REVOKED|SPVM::Net::SSLeay::X509_REVOKED>[] ();>
 
-Calls native L<get_REVOKED|https://docs.openssl.org/master/man3/X509_CRL_get0_by_serial/> function given the pointer value of the instance.
+Calls native L<get_REVOKED|https://docs.openssl.org/master/man3/get_REVOKED> function given the pointer value of the instance.
 
 And creates a new L<Net::SSLeay::X509_REVOKED|SPVM::Net::SSLeay::X509_REVOKED> array,
 
-And runs the following loop: copies the element at index $i of the return value(C<STACK_OF(X509_REVOKED)>) of the native function using native L<X509_REVOKED_dup|https://docs.openssl.org/1.1.1/man3/X509_dup/>, creates a new L<Net::SSLeay::X509_REVOKED|SPVM::Net::SSLeay::X509_REVOKED> object, sets the pointer value of the new object to the native copied value, and puses the new object to the new array.
+And runs the following loop: copies the element at index $i of the return value(C<STACK_OF(X509_REVOKED)>) of the native function using native L<X509_REVOKED_dup|https://docs.openssl.org/master/man3/X509_REVOKED_dup>, creates a new L<Net::SSLeay::X509_REVOKED|SPVM::Net::SSLeay::X509_REVOKED> object, sets the pointer value of the new object to the native copied value, and puses the new object to the new array.
 
 And returns the new array.
 
@@ -46,7 +46,7 @@ And returns the new array.
 
 C<method DESTROY : void ();>
 
-Calls native L<X509_CRL_free|https://docs.openssl.org/3.1/man3/X509_CRL_free/> function given the pointer value of the instance if C<no_free> flag of the instance is not a true value.
+Calls native L<X509_CRL_free|https://docs.openssl.org/master/man3/X509_CRL_free> function given the pointer value of the instance unless C<no_free> flag of the instance is a true value.
 
 =head1 FAQ
 
